@@ -1,4 +1,4 @@
 //! The echonet-lite prelude.
 
 pub use crate::el_packet::*;
-pub use crate::object::ClassPacket;
+pub use crate::object::{self, ClassPacket};
